{% extends "base.html" %}
{% load static core_tags i18n %}

{% block content %}
	<div class="list-inline">
		<h3>{{ question.title }}</h3>
		{% if form.answer.errors %}<p><strong>{{form.answer.errors|join:", " }}</strong></p>{% endif %}
		<form action="{% url 'molo.polls:free_text_vote' question.id %}" method="post">
			{% csrf_token %}
			{{form.answer}}
			<div>
				<input type="submit" value="{% trans "Vote" %}"/>
				<br>
				<a href="{{request.site.root_page.url}}">{% trans "Home" %}</a>
			</div>
		</form>
	</div>
{% endblock %}
