{% extends "base.html" %}
{% load i18n static core_tags %}

{% block content %}
	<div class="list-inline">
		{% if question.show_results and not question.freetextquestion%}
			<h4>{{ question.title }}</h4>
			<p>{% trans "Your answers:" %}</p>
				{% for choice in choices %}
					<span>{{ choice.title }}</span>
						{% if question.result_as_percentage %}
							{{ choice.percentage }}%
							<br>
						{% else %}
							{{ choice.votes }} vote{{ choice.votes|pluralize }}
							<br>
						{% endif %}
		      </span>
				{% endfor %}
		{% else %}
			<h4>{% trans "Thank you for voting!" %}</h4>
		{% endif %}
		<br>
	  <a href="{{request.site.root_page.url}}">{% trans "Home" %}</a>
	</div>
{% endblock %}
